# IOHGNBG

**IOHGNBG** also enables the integration of GNBG problems into IOHprofiler standards. It is provided as a library for use in the [GNBG Competition 2025](https://gecco-2025.sigevo.org/Competition?itemId=2781), with additional details available on the [competition website](https://dsmlossf.github.io/GNBG-Competition-2025/).

As part of the IOHprofiler ecosystem, IOHGNBG is actively developed, with ongoing updates to its features and interfaces.


## Installation

The minimum supported Python version is 3.10. Install IOHGNBG via pip and git:

```bash
pip install iohgnbg
```

## Tutorials

Explore the following Jupyter notebooks for step-by-step tutorials on using **IOHGNBG**:
1. [Random Search Tutorial ](https://github.com/IOHprofiler/IOHGNBG/blob/main/tutorials/random_search_tutorial.ipynb): Learn how to define a GNBG optimization problems, solve with Random Search and integrate with IOHinspector.

## License

This project is licensed under a standard BSD-3 clause License. See the LICENSE file for details.

## Acknowledgments

This work has been established as a collaboration between:
* Diederick Vermetten 
* Catalin-Viorel Dinu


